@@ -92,9 +92,9 @@ where
             (a, b),
             move |array, range, args| {
                 let (a, b) = args;
-                let mut exponential = Complex::<T>::from_polar(&T::one(), &b)
-                    * Complex::<T>::from_polar(&T::one(), &(a * T::from(range.start / 2).unwrap()));
-                let increment = Complex::<T>::from_polar(&T::one(), &a);
+                let mut exponential = Complex::<T>::from_polar(T::one(), b)
+                    * Complex::<T>::from_polar(T::one(), a * T::from(range.start / 2).unwrap());
+                let increment = Complex::<T>::from_polar(T::one(), a);
                 let array = array_to_complex_mut(array);
                 for complex in array {
                     *complex = (*complex) * exponential;
